Changelog 
==========

0.3b3 (2021-01-27)
------------------

- fix %(here)s replacement in rpm build
- release bump to morpfw-0.4.0b4

0.3b2 (2021-01-10)
------------------

- added missing buildout-rpm.cfg
- stop using bootstrap-buildout.py


0.3b1 (2020-12-29)
------------------

- Initial release with changelog


